Running the Tests
=================

The automatic unit tests can be run if `pytest` is installed.
In principle, these tests can be run without needing AiiDA to be
setup. It is enough for `aiida_core` to be installed correctly.

From a shell, run:

   .. code-block:: bash
       $ pytest -v

All available tests will be automatically discovered and executed.